braindecode.datasets package
============================

.. automodule:: braindecode.datasets
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

braindecode.datasets.base module
--------------------------------

.. automodule:: braindecode.datasets.base
   :members:
   :undoc-members:
   :show-inheritance:

braindecode.datasets.bbci module
--------------------------------

.. automodule:: braindecode.datasets.bbci
   :members:
   :undoc-members:
   :show-inheritance:

braindecode.datasets.bcic\_iv\_2a module
----------------------------------------

.. automodule:: braindecode.datasets.bcic_iv_2a
   :members:
   :undoc-members:
   :show-inheritance:

braindecode.datasets.croppedxy module
-------------------------------------

.. automodule:: braindecode.datasets.croppedxy
   :members:
   :undoc-members:
   :show-inheritance:

braindecode.datasets.datasets module
------------------------------------

.. automodule:: braindecode.datasets.datasets
   :members:
   :undoc-members:
   :show-inheritance:

